======
PyCADF
======

This library provides an auditing data model based on the `Cloud Auditing Data
Federation <http://www.dmtf.org/standards/cadf>`_ specification, primarily for
use by OpenStack.

Developer documentation, the source of which is in ``doc/source/``, is
published at:

    http://docs.openstack.org/developer/pycadf

Bugs and feature requests are tracked on Launchpad at:

    https://bugs.launchpad.net/pycadf

For information on contributing, see ``CONTRIBUTING.rst``.
